garanti/shared/focus

Values

pub fn filter_focused(
  suites: List(garanti.Suite),
) -> List(garanti.Suite)

Filter the given suites so that only focused suites remain.

When no suites are focused, all suites are returned.

pub fn is_focused_run(suites: List(garanti.Suite)) -> Bool

Whether the given suites contains at least one focused suite.

Search Document