garanti/shared/list_ext
Values
pub fn describe(list: List(a), limit: Int) -> String
Describe the given list by printing each element up to and inclusive the given limit.
If the list is contains more elements than the list, only the
Examples
list_ext.describe([1, 2, 3], 2)
// -> "[1, 2, ...] with a total of 3 element(s)"
pub fn remove_first(
from list: List(a),
where target: a,
) -> List(a)
Return a new list where the first occurance of the target element is removed.