garanti/shared/analysis
Types
Represents the different issues found during suite analysis.
pub type AnalysisResult {
DuplicateSuiteName(suite_name: String)
EmptySuite(suite_name: String)
}
Constructors
-
DuplicateSuiteName(suite_name: String)When more than one suite share the same name (case-insensitive).
-
EmptySuite(suite_name: String)A suite that contains no tests.
Values
pub fn analyse_suites(
suites: List(garanti.Suite),
) -> List(AnalysisResult)
Process the list of suites that was discovered and identify any potential problems with the prospects. This will not block any suites. As long as a suite compiles it will run, even when there are issues found.
Such as:
- Non-unique suite name.
- Empty suites.
pub fn describe_analysis_result(result: AnalysisResult) -> String
Describe the analysis result as a String.
pub fn perform_analysis(
suites: List(garanti.Suite),
) -> List(report.Message)